==> kadu_0.12.3.orig.tar.bz2: kadu-0.12.3/kadu-core/status/status-type-group.h <==
/*
 * %kadu copyright begin%
 * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
 * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
 * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
 * Copyright 2007, 2008, 2009, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
 * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
 * %kadu copyright end%
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef STATUS_TYPE_GROUP_H
#define STATUS_TYPE_GROUP_H

/**
 * @addtogroup Status
 * @{
 */

/**
 * @enum StatusTypeGroup
 * @author Rafał 'Vogel' Malinowski
 * @short Status type grouping enum.
 * @see StatusType
 *
 * This enum allows grouping of status types.
 */
enum StatusTypeGroup
{
	/**
	 * Empty (invalid) status type group.
	 */
	StatusTypeGroupNone = -1,
	/**
	 * Online status type group. Contains "Online" and "Free for chat" status types.
	 */
	StatusTypeGroupOnline = 0,
	/**
	 * Away status type group. Contains "Away", "Not available" and "Do not disturb" status types.
	 */
	StatusTypeGroupAway = 10,
	/**
	 * Invisible status type group. Contains "Invisible" status type.
	 */
	StatusTypeGroupInvisible = 20,
	/**
	 * Offline status type group. Contains "Offline" status type.
	 */
	StatusTypeGroupOffline = 30
};

/**
 * @addtogroup Status
 * @}
 */

#endif // STATUS_TYPE_GROUP_H

==> kadu_4.1.orig.tar.bz2: kadu-4.1/kadu-core/status/status-type-group.h <==
/*
 * %kadu copyright begin%
 * Copyright 2011 Rafał Przemysław Malinowski (rafal.przemyslaw.malinowski@gmail.com)
 * %kadu copyright end%
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef STATUS_TYPE_GROUP_H
#define STATUS_TYPE_GROUP_H

/**
 * @addtogroup Status
 * @{
 */

/**
 * @enum StatusTypeGroup
 * @author Rafał 'Vogel' Malinowski
 * @short Status type grouping enum.
 * @see StatusType
 *
 * This enum allows grouping of status types.
 */
enum class StatusTypeGroup
{
	/**
	 * Empty (invalid) status type group.
	 */
	None = -1,
	/**
	 * Online status type group. Contains "Online" and "Free for chat" status types.
	 */
	Online = 0,
	/**
	 * Away status type group. Contains "Away", "Not available" and "Do not disturb" status types.
	 */
	Away = 10,
	/**
	 * Invisible status type group. Contains "Invisible" status type.
	 */
	Invisible = 20,
	/**
	 * Offline status type group. Contains "Offline" status type.
	 */
	Offline = 30
};

/**
 * @addtogroup Status
 * @}
 */

#endif // STATUS_TYPE_GROUP_H
